##
##  paper.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_paper   2.3
%define       V_gnulib  20230618

#   package information
Name:         paper
Summary:      Paper Size Determination
URL:          https://github.com/rrthomas/paper
Vendor:       Thomas Reuben
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Print
License:      GPL
Version:      %{V_paper}
Release:      20230618

#   list of sources
Source0:      https://github.com/rrthomas/paper/archive/v%{V_paper}.tar.gz
Source1:      http://download.openpkg.org/components/versioned/gnulib/gnulib-%{V_gnulib}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, autoconf, automake, libtool, perl
PreReq:       OpenPKG, openpkg >= 20160101

%description
    The paper package enables users to indicate their preferred paper
    size, provides the paper(1) utility to find the user's preferred
    default paper size and give information about known sizes, and
    specifies system-wide and per-user paper size catalogues, which can
    be can also be used directly (see paperspecs(5)).

%track
    prog paper:paper = {
        version   = %{V_paper}
        url       = https://github.com/rrthomas/paper/releases
        regex     = v(__VER__)\.tar\.gz
    }
    prog paper:gnulib = {
        version   = %{V_gnulib}
        url       = http://download.openpkg.org/components/versioned/gnulib/
        regex     = gnulib-(__VER__)\.tar\.xz
    }

%prep
    %setup -q
    %setup -q -T -D -a 1

%build
    %{l_shtool} subst \
        -e 's;#!/usr/bin/env perl;#!%{l_prefix}/bin/perl;g' \
        src/paper.in.in
    ./bootstrap \
        --skip-git \
        --gnulib-srcdir=gnulib
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/paper \
        --libexecdir=%{l_prefix}/libexec/paper \
        --mandir=%{l_prefix}/man
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/paper/*'

%files -f files

%clean

